@@ -23,6 +23,8 @@ class Common:
     Attachments     = []
     Recipients      = []
 
+    SendMode        = ""
+
     """ Constructor """
     def __init__(self,kwargs):
 
@@ -65,12 +67,17 @@ class Common:
 
         if "Attachments" in kwargs:
             self.AddAttachment(kwargs.pop("Attachments"))
+        
+        if "SendMode" in kwargs:
+            self.SendMode = kwargs.pop("SendMode")
 
     """ Add Recipient """
     def AddRecipient(self, recipient):
 
         if recipient:
 
+            #print(isinstance(recipient,dict))
+
             if isinstance(recipient,str):
 
                 dest = {
@@ -88,6 +95,10 @@ class Common:
                     }
 
                     self.Recipients.append(dest)
+
+            if isinstance(recipient,dict):
+
+                self.Recipients.append(recipient)
             
 
     """ Add Attachment """
